package com.lemon.lifecenter.service;

import java.util.HashMap;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.lemon.lifecenter.dto.CenterInfoDTO;
import com.lemon.lifecenter.dto.LocationDTO;
import com.lemon.lifecenter.mapper.CenterMapper;

@Service
public class CenterService {
    
    @Autowired
    private CenterMapper mapper;
    
    public List<LocationDTO> selectLocation() {
        return mapper.selectLocation();
    }
    
    public void insertCenter(CenterInfoDTO dto) throws Exception {
        mapper.insertCenter(dto);
    }
    
    public CenterInfoDTO selectCenterInfo(CenterInfoDTO dto) {
        return mapper.selectCenterInfo(dto);
    }
    
    public int selectCenterCount(CenterInfoDTO dto) {
        return mapper.selectCenterCount(dto);
    }
    
    public List<CenterInfoDTO> selectCenterList(CenterInfoDTO dto) {
        return mapper.selectCenterList(dto);
    }
    
    public Integer updateCenterInfo(CenterInfoDTO dto) {
        return mapper.updateCenterInfo(dto);
    }
}
